@@ -153,8 +153,9 @@ class MD2(Mesh):
     def __init__(self, filename: str = "", texture_filename: str = "", **kwargs: Any):
         """Initialize the MD2 Object
 
-        Args:
-          filename: Filename to load
+        Keyword arguments:
+        filaname -- Filename to load
+        texture_filename -- Texture filaname for the MD2 Object
         """
         super().__init__(**kwargs)
         self.header: MD2Header = MD2Header()
@@ -180,7 +181,13 @@ class MD2(Mesh):
     def add_frame_child(self, name: str, mesh: Mesh) -> None:
         self._frame_children[name] = mesh
 
-    def bake_animation(self, animation_name: str, from_frame: int, to_frame: int, steps: int = 1,) -> None:
+    def bake_animation(
+        self,
+        animation_name: str,
+        from_frame: int,
+        to_frame: int,
+        steps: int = 1,
+    ) -> None:
         """Original MD2 Format does not include all frames in an animation.
 
         Instead, there are "key frames". There are gaps between the key-frames
@@ -188,16 +195,22 @@ class MD2(Mesh):
         between key-frames. Bake Animation method simply fills these gaps by
         calculating the N steps between key-frames. This gives you a smooth
         animation.
+
+        Keyword arguments:
+        animation_name -- Animation name to bake
+        from_frame -- Starting frame for baking
+        to_frame -- Ending frame for baking
+        steps -- Number of steps to interpolate.
         """
         if animation_name not in self.animations:
             logging.error(f"Animation {animation_name} not found in object")
             return
         anim = self.animations[animation_name]
         if from_frame < anim[0] or from_frame > anim[1]:
-            logging.error(f"from_frame out of bounds")
+            logging.error("from_frame out of bounds")
             return
         if to_frame < anim[0] or to_frame > anim[1]:
-            logging.error(f"to_frame out of bounds")
+            logging.error("to_frame out of bounds")
             return
 
         frames = []
@@ -221,15 +234,19 @@ class MD2(Mesh):
         self.animations[animation_name] = [0, len(frames) - 1]
 
     def animate(
-        self, animation_name: str, from_frame: int, to_frame: int, loop: bool = True,
+        self,
+        animation_name: str,
+        from_frame: int,
+        to_frame: int,
+        loop: bool = True,
     ):
         """Set the model in motion
 
-        Args:
-          animation_name: Name of the animation to play
-          from_frame: Loop starting frame
-          to_frame: Loop ending frame
-          loop: Loop the animation?
+        Keyword arguments
+        animation_name -- Name of the animation to play
+        from_frame -- Loop starting frame
+        to_frame -- Loop ending frame
+        loop -- Loop the animation?
         """
         self.animation = ""  # For thread safety
         if animation_name not in self.animations:
@@ -237,10 +254,10 @@ class MD2(Mesh):
             return
         anim = self.animations[animation_name]
         if from_frame < anim[0] or from_frame > anim[1]:
-            logging.error(f"from_frame out of bounds")
+            logging.error("from_frame out of bounds")
             return
         if to_frame < anim[0] or to_frame > anim[1]:
-            logging.error(f"to_frame out of bounds")
+            logging.error("to_frame out of bounds")
             return
         self._loop = loop
         self._active_frame = from_frame
@@ -252,28 +269,9 @@ class MD2(Mesh):
             child_obj = cast(MD2, self.children[child])
             child_obj.animate(animation_name, from_frame, to_frame, loop)
 
-    def render(
-        self, lit: bool, shader: Shader, parent_matrix: Optional[np.ndarray] = None, _primitive: int = None,
-    ) -> None:
-        if not self._visible:
-            return
-
-        self.update_matrix(parent_matrix=parent_matrix)
-        self.track()
-
-        # Render motion path
-        if self.track_motion:
-            self._motion_path_line.render(lit, shader, parent_matrix)
-
-        if self.animation == "":
-            for child in self._frame_children:
-                self._frame_children[child].render(lit, shader, self._model_matrix)
-                break
-                # render children
-            for child in self.children:
-                self.children[child].render(lit, shader, self._model_matrix)
-            return
-
+    @property
+    def frame(self) -> str:
+        """Get the current frame name as <animation_name><frame_number>"""
         if self._time == 0:
             self._time = time.time()
 
@@ -292,12 +290,48 @@ class MD2(Mesh):
             self._time = time.time()
 
         frame_name = f"{self.animation}{self._active_frame}"
+        return frame_name
 
-        self._frame_children[frame_name].render(lit, shader, self._model_matrix)
+    def render(
+        self,
+        lit: bool,
+        shader: Shader,
+        parent_matrix: Optional[np.ndarray] = None,
+        _primitive: int = None,
+    ) -> None:
+        """Main render cycle for the MD2 Object
+
+        Keyword arguments:
+        lit -- Is this an illuminated object?
+        shader -- Shader to use for rendering
+        parent_matrix -- Matrix of the parent object if exists
+        _primitive -- Enforced OpenGL primitive to render"""
+        if not self._visible:
+            return
+
+        self.update_matrix(parent_matrix=parent_matrix)
+        self.track()
+
+        # Render motion path
+        if self.track_motion:
+            self._motion_path_line.render(lit, shader, parent_matrix)
+
+        if self.animation == "":
+            next(iter(self._frame_children.values())).render(lit, shader, self._model_matrix)
+            for child in self.children:
+                self.children[child].render(lit, shader, self._model_matrix)
+            return
+
+        self._frame_children[self.frame].render(lit, shader, self._model_matrix)
         for child in self.children:
             self.children[child].render(lit, shader, self._model_matrix)
 
     def load_file(self, filename: str):
+        """Load MD2 file
+
+        Keyword arguments:
+        filaname -- MD2 Filaname to load.
+        """
         if not os.path.exists(filename):
             raise BaseException(f"File not found: {filename}")
         self._path = os.path.dirname(os.path.abspath(filename))
@@ -305,6 +339,7 @@ class MD2(Mesh):
             self.load_buffer(f)
 
     def load_buffer(self, f: BinaryIO):
+        """Load MD2 buffer into memory and compile the object"""
         self.read_header(f)
         self.read_skin(f)
         self.read_tex_coords(f)
@@ -346,7 +381,8 @@ class MD2(Mesh):
             t1 = cast(np.ndarray, self._texcoords[self.triangle_layout.tc_indices[i][2]]).tolist()
 
             mesh.add_triangle(
-                vertices=[v1, v2, v3], texcoords=[t1, t2, t3],
+                vertices=[v1, v2, v3],
+                texcoords=[t1, t2, t3],
             )
 
         mesh.fix_normals(False)
@@ -407,6 +443,7 @@ class MD2(Mesh):
         return MD2Frame(name=name, vertices=vertices)
 
     def to_dict(self) -> Dict[str, Any]:
+        """Convert the MD2 Object to Dictionary"""
         animation = self.animation
         if animation == "":
             animation = list(self.animations.keys())[0]
@@ -418,6 +455,7 @@ class MD2(Mesh):
         return result
 
     def set_texture(self, texture_filename: str):
+        """Set the object texture filaname"""
         for m in self.children.values():
             m.material.texture = texture_filename
             m.material.refresh()
